diff --git a/src/dags/libs/handle_file.py b/src/dags/libs/handle_file.py
index a8186e70fa747ce74ebb41ae8fe8d21f147704c3..45caf1f38a1c971eef650d810274068ac67fe5da 100644
--- a/src/dags/libs/handle_file.py
+++ b/src/dags/libs/handle_file.py
@@ -75,12 +75,12 @@ class FileHandler(HeadersMixin):
         self.token_refresher = token_refresher
         self._blob_storage_client = blob_storage_client or blob_storage.get_client()
 
-    def _get_file_from_preload_path(self, preload_path: str,
+    def _get_file_from_preload_path(self, preload_file_path: str,
                                     file: FileLikeObject) -> Tuple[FileLikeObject, str]:
         """Get file from a preloaded path.
 
         :param preload_path: Full URI of the file to obtain
         :type preload_path: str
         :return: Raw file data and content-type
         :rtype: Tuple[FileLikeObject, str]
         """
@@ -75,12 +75,12 @@ class FileHandler(HeadersMixin):
         """Get file from a preloaded path.
 
-        :param preload_path: Full URI of the file to obtain
-        :type preload_path: str
+        :param preload_file_path: Full URI of the file to obtain
+        :type preload_file_path: str
         :return: Raw file data and content-type
         :rtype: Tuple[FileLikeObject, str]